library(tidyverse)
library(dataRetrieval)
source('functions/themebox.R') #function for specifying logarithmic y-axis breaks
source('functions/logtickmark.R') #function for specifying logarithmic y-axis breaks  
options(scipen=999) #removing scientific notation 

TRENTONFlow <- readNWISdv(siteNumber='01463500',parameterCd=c("00060")) #Importing USGS average daily flow values for Trenton, NJ 

setwd("figures/")

Flow_Exceedance<-TRENTONFlow %>% 
  mutate(my_rank = 1 - percent_rank(X_00060_00003)) %>%     #transforming flow values into a ranked percentage 
  mutate(my_rank = if_else(my_rank == 0.01, 1, my_rank)) %>%   
  ggplot(aes(my_rank,X_00060_00003)) +
  geom_line(size=2) +
  ggtitle("Trenton New Jersey - Flow Duration Curve") +
  scale_y_log10(name = 'Predicted daily flows (cfs)',
                breaks = logTicks(n = 10), #1,2,4,10,100, etc. outline how many major base pair ticks marks
                minor_breaks = logTicks(n=100))+  #outline how many minor base pair ticks marks; keep in mind logarithmic
  scale_x_continuous(name = 'Percentage of time flow exceeded')+
  themebox()
ggsave("Flow_Exceedance.png")

setwd("./..")
