#Outputting a logarithmic tick mark/grid. 
# log scale tick marks and/or grid
#' @param n Approximate number of ticks to produce
#' @param NumBase Logarithm base

logTicks <- function(n = 5, base = 10){ ##n indicated number of logarithm base ticks marks. e.g., base 10: 1, 2, 5, 10.
  divisors <- which((base / seq_len(base)) %% 1 == 0)
  mkTcks <- function(min, max, NumBase, divisor){
    f <- seq(divisor, base, by = divisor)
    return(unique(c(base^min, as.vector(outer(f, base^(min:max), `*`)))))
  }
  function(x) {
    rng <- range(x, na.rm = TRUE)
    lrng <- log(rng, base = base)
    min <- floor(lrng[1])
    max <- ceiling(lrng[2])
    
    tck <- function(divisor){
      t <- mkTcks(min, max, NumBase, divisor)
      t[t >= rng[1] & t <= rng[2]]
    }
    # produce a set of ticks and count how many ticks
    tcks <- lapply(divisors, function(d) tck(d))
    l <- vapply(tcks, length, numeric(1))
    
    # Take the set of ticks which is nearest to the desired number of ticks
    i <- which.min(abs(n - l))
    if(l[i] < 2){
      ticks <- pretty(x, n = n, min.n = 2)
    }else{
      ticks <- tcks[[i]]
    }
    return(ticks)
  }
}